import { render, screen } from '@testing-library/react'
import { DataloadSectionType, FluidType } from 'enums'
import React from 'react'
import { baseDataLoad } from 'tests/__mocks__/chartData.mock'
import DataloadSection from './DataloadSection'

jest.mock(
  'components/ConsumptionVisualizer/DataloadSectionValue',
  () => 'mock-dataloadsectionvalue'
)
jest.mock(
  'components/ConsumptionVisualizer/DataloadSectionDetail',
  () => 'mock-dataloadsectiondetail'
)

describe('DataloadSection component', () => {
  it('should render correctly', () => {
    const { container } = render(
      <DataloadSection
        dataload={baseDataLoad}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.NO_COMPARE}
        toggleEstimationModal={jest.fn()}
      />
    )
    expect(container).toMatchSnapshot()
  })

  it('should render no_data when dataload value is -1 and section is left', () => {
    const mockDataLoad = { ...baseDataLoad, value: -1 }
    render(
      <DataloadSection
        dataload={mockDataLoad}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.LEFT}
        toggleEstimationModal={jest.fn()}
      />
    )
    expect(
      screen.getByText('consumption_visualizer.no_data')
    ).toBeInTheDocument()
  })
})
