import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import {
  mockEcogestureAnswer,
  mockProfileEcogesture,
} from 'tests/__mocks__/profileEcogesture.mock'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import EcogestureFormSingleChoice from './EcogestureFormSingleChoice'

jest.mock(
  'components/Ecogesture/EcogestureInitModal/EcogestureInitModal',
  () => 'mock-ecogestureinitmodal'
)

const mockHandleNextStep = jest.fn()
const mockHandlePreviousStep = jest.fn()
describe('EcogestureFormSingleChoice component', () => {
  const store = createMockEcolyoStore()

  it('should be rendered correctly', () => {
    const { container } = render(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    expect(container).toMatchSnapshot()
  })

  it('should pick a choice and go next', async () => {
    render(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await userEvent.click(screen.getAllByRole('radio')[0])
    await userEvent.click(
      screen.getByLabelText('profile_type.accessibility.button_next')
    )
    expect(mockHandleNextStep).toHaveBeenCalledTimes(1)
  })
  it('should go back', async () => {
    render(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={1}
          viewedStep={0}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )
    await userEvent.click(
      screen.getByLabelText('profile_type.accessibility.button_previous')
    )
    expect(mockHandlePreviousStep).toHaveBeenCalledTimes(1)
  })
  it('should keep previous answer', () => {
    render(
      <Provider store={store}>
        <EcogestureFormSingleChoice
          step={0}
          viewedStep={1}
          setNextStep={mockHandleNextStep}
          setPreviousStep={mockHandlePreviousStep}
          currentProfileEcogesture={mockProfileEcogesture}
          answerType={mockEcogestureAnswer}
        />
      </Provider>
    )

    const radio = screen.getByRole('radio', { checked: true })
    expect(radio).toBeInTheDocument()
  })
})
