/* eslint-disable jsx-a11y/no-noninteractive-tabindex */
/* eslint-disable jsx-a11y/no-noninteractive-element-interactions */
import { Button } from '@material-ui/core'
import { useI18n } from 'cozy-ui/transpiled/react/providers/I18n'
import { FluidType, TimeStep } from 'enums'
import { DateTime } from 'luxon'
import React from 'react'
import DateChartService from 'services/dateChart.service'
import {
  setCurrentIndex,
  setCurrentTimeStep,
  setSelectedDate,
} from 'store/chart/chart.slice'
import { useAppDispatch, useAppSelector } from 'store/hooks'
import './timeStepSelector.scss'

const TimeStepSelector = ({ fluidType }: { fluidType: FluidType }) => {
  const { t } = useI18n()
  const dispatch = useAppDispatch()
  const { currentTimeStep, selectedDate } = useAppSelector(
    state => state.ecolyo.chart
  )
  const dateChartService = new DateChartService()
  const timeStepMultiArray: TimeStep[] = [
    TimeStep.WEEK,
    TimeStep.DAY,
    TimeStep.MONTH,
    TimeStep.YEAR,
  ]
  const timeStepArray: TimeStep[] =
    fluidType === FluidType.ELECTRICITY
      ? [TimeStep.HALF_AN_HOUR, ...timeStepMultiArray]
      : [...timeStepMultiArray]

  const handleToday = () => {
    const today = DateTime.local()
      .setZone('utc', {
        keepLocalTime: true,
      })
      .startOf('day')
    dispatch(setCurrentIndex(0))
    dispatch(setSelectedDate(today))
    dispatch(setCurrentTimeStep(TimeStep.WEEK))
  }
  const handleChangeTimeStep = (targetTimestep: TimeStep) => {
    const index = dateChartService.defineDateIndex(targetTimestep, selectedDate)
    dispatch(setCurrentTimeStep(targetTimestep))
    dispatch(setCurrentIndex(index))
  }
  return (
    <div className="timestep-selector">
      <Button
        onClick={handleToday}
        classes={{
          root: 'btnSecondary',
          label: 'text-13-normal',
        }}
        size="large"
      >
        {t('timestep.today')}
      </Button>
      <div className="timestep-container">
        <ul
          className={`timestep-bar ${
            fluidType === FluidType.ELECTRICITY && 'elec-bar'
          }`}
        >
          {timeStepArray.map(step => (
            <React.Fragment key={step}>
              <li
                className={
                  step === currentTimeStep ? 'active circle' : 'circle'
                }
                onClick={() => handleChangeTimeStep(step)}
                onKeyDown={event => {
                  if (event.key === ' ') {
                    event.preventDefault()
                    handleChangeTimeStep(step)
                  }
                }}
                id={TimeStep[step].toLowerCase()}
                tabIndex={0}
              >
                <span className="clickable-area" />
                <span className="text text-14-normal">
                  {t(`timestep.${TimeStep[step].toLowerCase()}.period`)}
                </span>
              </li>
              <li className="bar" />
            </React.Fragment>
          ))}
        </ul>
      </div>
    </div>
  )
}

export default TimeStepSelector
