import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import React from 'react'
import { Provider } from 'react-redux'
import { createMockEcolyoStore } from 'tests/__mocks__/store'
import { userChallengeData } from 'tests/__mocks__/userChallengeData.mock'
import QuizQuestionContent from './QuizQuestionContent'

const mockedNavigate = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useNavigate: () => mockedNavigate,
}))

jest.mock('services/quiz.service', () => {
  return jest.fn(() => ({
    updateUserQuiz: jest.fn(),
  }))
})

jest.mock('services/challenge.service', () => {
  return jest.fn(() => ({
    updateUserChallenge: jest.fn(),
  }))
})

describe('QuizQuestionContent component', () => {
  const store = createMockEcolyoStore()
  it('should be rendered correctly', () => {
    render(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
          focusCallback={jest.fn()}
        />
      </Provider>
    )
    expect(
      screen.getByText(userChallengeData[0].quiz.questions[0].questionLabel)
    ).toBeInTheDocument()
    expect(screen.getAllByRole('radio').length).toBe(3)
  })
  it('should redirect to challenge on click on btn-back', async () => {
    render(
      <Provider store={store}>
        <QuizQuestionContent
          userChallenge={userChallengeData[0]}
          setIsCustomQuest={() => false}
          goBack={mockedNavigate('/challenges')}
          focusCallback={jest.fn()}
        />
      </Provider>
    )
    await userEvent.click(screen.getAllByRole('button')[0])
    expect(mockedNavigate).toHaveBeenCalledWith('/challenges')
  })
})
