import EnvironmentService from './environment.service'

declare const global: {
  __IS_ALPHA__: boolean
  __DEVELOPMENT__: boolean
}

describe('Environment service', () => {
  const environmentService = new EnvironmentService()

  describe('isProduction()', () => {
    it('should return true and prod url', () => {
      global.__IS_ALPHA__ = false
      const result = environmentService.isProduction()
      expect(result).toEqual(true)
      const url = environmentService.getPublicURL()
      expect(url).toEqual('https://ecolyo-agent.apps.grandlyon.com')
    })

    it('should return false and rec url, alpha case', () => {
      global.__IS_ALPHA__ = true
      const result = environmentService.isProduction()
      expect(result).toEqual(false)
      const url = environmentService.getPublicURL()
      expect(url).toEqual('https://ecolyo-agent-rec.apps.grandlyon.com')
    })
  })

  describe('isAlpha()', () => {
    it('should return false', () => {
      global.__IS_ALPHA__ = false
      expect(environmentService.isAlpha()).toBe(false)
    })
    it('should return true', () => {
      global.__IS_ALPHA__ = true
      expect(environmentService.isAlpha()).toBe(true)
    })
  })

  describe('isLocal()', () => {
    it('should return false', () => {
      global.__DEVELOPMENT__ = false
      expect(environmentService.isLocal()).toBe(false)
    })
    it('should return true', () => {
      global.__DEVELOPMENT__ = true
      expect(environmentService.isLocal()).toBe(true)
    })
  })

  describe('isDev()', () => {
    it('should return false', () => {
      global.__DEVELOPMENT__ = false
      global.__IS_ALPHA__ = false
      expect(environmentService.isDev()).toBe(false)
    })
    it('should return true', () => {
      global.__DEVELOPMENT__ = true
      global.__IS_ALPHA__ = false
      expect(environmentService.isDev()).toBe(true)

      global.__DEVELOPMENT__ = false
      global.__IS_ALPHA__ = true
      expect(environmentService.isDev()).toBe(true)

      global.__DEVELOPMENT__ = true
      global.__IS_ALPHA__ = true
      expect(environmentService.isDev()).toBe(true)
    })
  })
})
